==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/csession.cpp <==
/***************************************************************************
                          csession.cpp  -  basis of multi-world support
                              -------------------
    begin                : Pi nov 15 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <config.h>

#include "csession.h"

#include "cansiparser.h"
#include "ccmdprocessor.h"
#include "cconnection.h"
#include "cconsole.h"
#include "cgaugebar.h"
#include "cinputline.h"
#include "cmultiinputline.h"
#include "cprompt.h"
#include "csendcmd.h"
#include "cstatus.h"
#include "ctelnet.h"
#include "ctextprocessor.h"
#include "ctranscript.h"

#ifdef HAVE_MXP
#include "cmxpconsole.h"
#include "cmxpmanager.h"
#endif  //HAVE_MXP

#include <kapp.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kpushbutton.h>
#include <kstatusbar.h>

#include <qtooltip.h>

cSession::cSession (QWidget *parent, const char *name) :
    QVBox (parent, name)
{
  _flashing = false;
  defaultName = true;

  //create objects
  _telnet = new cTelnet;
  _telnet->setSession (this);
#ifdef HAVE_MXP
  _mxpmanager = new cMXPManager;
  _mxpmanager->setSession (this);
#endif
  _sendcmd = new cSendCmd;
  _sendcmd->setSession (this);
  _ansiparser = new cANSIParser;
  _ansiparser->setSession (this);
  _cmdproc = new cCmdProcessor;
  _cmdproc->setSession (this);
  _textproc = new cTextProcessor;
  _textproc->setSession (this);
  _connection = new cConnection;
  _connection->setSession (this);
  
  _console = new cConsole (false, this);
  _console->setSession (this);
  _console->auxConsole()->setSession (this);
  
  QHBox *promptinput = new QHBox (this);
  _prompt = new cPrompt(promptinput);
  
  _auxinputline = new cInputLine (this);
  _auxinputline->setSession (this);
  _auxinputline->initialize ();
  _auxinputline->hide ();
  
  _inputline = new cInputLine (promptinput);
  _inputline->setSession (this);
  _inputline->initialize ();
  
  _multiinputline = new cMultiInputLine (promptinput);
  _multiinputline->setSession (this);
  _multiinputline->hide ();
  QToolTip::add (_multiinputline, i18n ("Ctrl+Enter adds new line, unless changed in settings"));
  
  KPushButton *switchlinebutton = new KPushButton (promptinput);
  KIconLoader *icons = (KApplication::kApplication())->iconLoader ();
  switchlinebutton->setPixmap (icons->loadIcon ("text_center", KIcon::Small, 16));
  QToolTip::add (switchlinebutton, i18n ("Switches between standard and multi-line input line."));
  
  //the button should take as few space as possible
  switchlinebutton->setSizePolicy (QSizePolicy::Fixed, QSizePolicy::Minimum);
  switchlinebutton->setFocusPolicy (QWidget::NoFocus);
  
  _gaugebar = new cGaugeBar (this);
  _gaugebar->setSession (this);
  _gaugebar->hide();

  KStatusBar *statusbar = new KStatusBar (this);
  _status = new cStatus (statusbar);
  _status->setSession (this);

  _transcript = new cTranscript;
  _transcript->setSession (this);

  //--- establish connections between objects ---

  //telnet->preprocessor->ansi parser->textproc->console - text displaying
  connect (_telnet, SIGNAL (dataReceived (const QString &)),
      _textproc, SLOT (preprocess (const QString &)));
  connect (_textproc, SIGNAL (preprocessed (const QString &)),
      _textproc, SLOT (parseText (const QString &)));
  connect (_textproc, SIGNAL (plainText (const QString &)),
      _ansiparser, SLOT (parseText (const QString &)));
  connect (_ansiparser, SIGNAL (fgColor (QColor)), _textproc, SLOT (gotFgColor (QColor)));
  connect (_ansiparser, SIGNAL (bgColor (QColor)), _textproc, SLOT (gotBgColor (QColor)));
  connect (_ansiparser, SIGNAL (attrib (int)), _textproc, SLOT (gotAttrib (int)));
  connect (_ansiparser, SIGNAL (plainText (const QString &)),
      _textproc, SLOT (gotNewText (const QString &)));
  connect (_textproc, SIGNAL (displayLine (cTextChunk *)),
    _console, SLOT (addLine (cTextChunk *)));
  connect (_textproc, SIGNAL (displayPrompt (cTextChunk *)),
    _console, SLOT (addText (cTextChunk *)));
  connect (_telnet, SIGNAL (receivedGA ()), _textproc, SLOT (receivedGA ()));
  connect (_telnet, SIGNAL (moreTextHere ()), _textproc, SLOT (moreTextHere ()));
  
#ifdef HAVE_MXP
  //MXP processing
  connect (_mxpmanager, SIGNAL (gotNewText (const QString &)),
      _ansiparser, SLOT (parseText (const QString &)));
  connect (_mxpmanager, SIGNAL (gotNewLine ()),
      _textproc, SLOT (gotNewLine ()));
  connect (_mxpmanager, SIGNAL (gotFgColor (QColor)),
      _textproc, SLOT (gotFgColor (QColor)));
  connect (_mxpmanager, SIGNAL (gotBgColor (QColor)),
      _textproc, SLOT (gotBgColor (QColor)));
  connect (_mxpmanager, SIGNAL (gotAttrib (int)),
      _textproc, SLOT (gotAttrib (int)));
  connect (_mxpmanager, SIGNAL (gotALink (const QString &, const QString &, const QString &,
      const QString &)), _textproc, SLOT (gotALink (const QString &, const QString &,
      const QString &, const QString &)));
  connect (_mxpmanager, SIGNAL (gotSENDLink (const QString &, const QString &, const QString &,
      const QString &, bool, bool)), _textproc, SLOT (gotSENDLink (const QString &,
      const QString &, const QString &, const QString &, bool, bool)));
  connect (_mxpmanager, SIGNAL (gotExpire (const QString &)),
      _console, SLOT (expireNamedLinks (const QString &)));
      
  //MXP error reporting
  cMXPConsole *mxpc = cMXPConsole::self();
  connect (_mxpmanager, SIGNAL (mxpWarning (cSession *, const QString &)), mxpc,
      SLOT (addWarning (cSession *, const QString &)));
  connect (_mxpmanager, SIGNAL (mxpError (cSession *, const QString &)), mxpc,
      SLOT (addError (cSession *, const QString &)));
#endif //HAVE_MXP
  
  //dimensions...
  connect (_console, SIGNAL (dimensionsChanged (int, int)),
    _telnet, SLOT (windowSizeChanged (int, int)));

  //command sending
  connect (_telnet, SIGNAL (cmdRequest ()), _sendcmd, SLOT (oneCommandSender ()));
  connect (_sendcmd, SIGNAL (commandReady (const QString &, bool, bool)),
    _telnet, SLOT (sendData (const QString &, bool, bool)));
  connect (_sendcmd, SIGNAL (commandSent (const QString &)),
    _console, SLOT (addCommand (const QString &)));

  //command processing
  connect (_inputline, SIGNAL (returnPressed (const QString &)),
    _cmdproc, SLOT (processInput (const QString &)));
  connect (_auxinputline, SIGNAL (returnPressed (const QString &)),
    _cmdproc, SLOT (processInput (const QString &)));
  connect (_multiinputline, SIGNAL (commandEntered (const QString &)),
    _cmdproc, SLOT (processInput (const QString &)));
  connect (_cmdproc, SIGNAL (newCommand (const QString &)),
    _sendcmd, SLOT (addCommand (const QString &)));

  //the button switches between standard input and multi-line input
  connect (switchlinebutton, SIGNAL (clicked ()), this, SLOT (switchInputLines ()));
    
  //command-links
  //sending clicks on command-links - NOT via command processor - we don't want macro expansion
  connect (_console, SIGNAL (sendCommand (const QString &)),
    _sendcmd, SLOT (addCommand (const QString &)));
  //putting a command to the prompt
  connect (_console, SIGNAL (promptCommand (const QString &)),
    _inputline, SLOT (setText (const QString &)));
    
  //session transcript
  connect (_telnet, SIGNAL (disconnected ()), _transcript, SLOT (stopTranscript ()));
  connect (_telnet, SIGNAL (disconnected ()), _transcript, SLOT (stopAdvTranscript ()));
  connect (_textproc, SIGNAL (displayLine (cTextChunk *)),
    _transcript, SLOT (addLineToTranscript (cTextChunk *)));
  connect (_textproc, SIGNAL (displayLine (cTextChunk *)),
    _transcript, SLOT (addLineToAdvTranscript (cTextChunk *)));
  //prompt is added as a separate line; this is to prevent problems when
  //command displaying is off
  connect (_textproc, SIGNAL (displayPrompt (cTextChunk *)),
    _transcript, SLOT (addLineToTranscript (cTextChunk *)));
  connect (_textproc, SIGNAL (displayPrompt (cTextChunk *)),
    _transcript, SLOT (addLineToAdvTranscript (cTextChunk *)));
  connect (_console, SIGNAL (commandDisplayed (const QString &)),
    _transcript, SLOT (addCommandToTranscript (const QString &)));
  connect (_console, SIGNAL (scriptOutputDisplayed (const QString &)),
    _transcript, SLOT (addScriptOutputToTranscript (const QString &)));

  //status-bar
  connect (_console, SIGNAL (dimensionsChanged (int, int)),
    _status, SLOT (dimensionsChanged (int, int)));
  connect (_telnet, SIGNAL (connected()), _status, SLOT (connected ()));
  connect (_telnet, SIGNAL (disconnected()), _status, SLOT (disconnected ()));
  connect (_telnet, SIGNAL (connected()), _status, SLOT (timerStart ()));
  connect (_telnet, SIGNAL (connected()), _status, SLOT (timerReset ()));
  connect (_telnet, SIGNAL (disconnected()), _status, SLOT (timerStop ()));
  connect (_textproc, SIGNAL (receivedPrompt (const QString &)),
    _status, SLOT (partialLine (const QString &)));
  connect (_textproc, SIGNAL (showPartialLine (const QString &)),
    _status, SLOT (partialLine (const QString &)));
  connect (_textproc, SIGNAL (receivedPrompt(const QString &)),
    _console, SLOT (updatePrompt (const QString &)));
  connect (_sendcmd, SIGNAL (commandSent (const QString &)),
    _status, SLOT (gotCommand (const QString &)));

  //clear console, counters and internal buffers on connect
  connect (_telnet, SIGNAL (connected ()), _console, SLOT (connected ()));
  connect (_telnet, SIGNAL (connected ()), _ansiparser, SLOT (flush ()));
  connect (_telnet, SIGNAL (connected ()), _textproc, SLOT (flush ()));
  connect (_telnet, SIGNAL (connected ()), _sendcmd, SLOT (reset ()));
#ifdef HAVE_MXP
  connect (_telnet, SIGNAL (connected ()), _mxpmanager, SLOT (reset ()));
#endif

  KApplication::kApplication()->processEvents ();

}

cSession::~cSession ()
{
  //transcript must be deleted before the console!
  delete _transcript;
  _transcript = 0;

  delete _status;  //this also destroys the statusbar
  _status = 0;
  delete _multiinputline;
  _multiinputline = 0;
  delete _auxinputline;
  _auxinputline = 0;
  delete _inputline;
  _inputline = 0;
  delete _console;
  _console = 0;
  delete _prompt;
  _prompt = 0;

  delete _connection;
  _connection = 0;
  delete _textproc;
  _textproc = 0;
  delete _cmdproc;
  _cmdproc = 0;
  delete _ansiparser;
  _ansiparser = 0;
  delete _sendcmd;
  _sendcmd = 0;
  delete _telnet;
  _telnet = 0;
  
}

void cSession::setName (const QString &name, bool defName)
{
  //don't overwrite non-default name with a default one
  if (defName && (!defaultName))
    return;
  
  _name = name;
  defaultName = defName;
}

void cSession::setAuxInput (bool val)
{
  val ? _auxinputline->show () : _auxinputline->hide ();
}

void cSession::switchInputLines ()
{
  if (_inputline->isVisible())
  {
    _inputline->hide();
    _multiinputline->show();
    _multiinputline->setFocus ();
  }
  else
  {
    _multiinputline->hide();
    _inputline->show();
    _inputline->setFocus ();
  }
}

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/csession.cpp <==
/***************************************************************************
                          csession.cpp  -  basis of multi-world support
                              -------------------
    begin                : Pi nov 15 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <config.h>

#include "csession.h"

#include "cansiparser.h"
#include "ccmdparser.h"
#include "ccmdprocessor.h"
#include "ccmdqueues.h"
#include "cconnection.h"
#include "cgaugebar.h"
#include "cinputline.h"
#include "cmultiinputline.h"
#include "coutput.h"
#include "cprompt.h"
#include "cstatus.h"
#include "ctelnet.h"
#include "ctextprocessor.h"
#include "ctranscript.h"

#ifdef HAVE_MXP
#include "cmxpmanager.h"
#endif  //HAVE_MXP

#include <kapp.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kpushbutton.h>
#include <kstatusbar.h>

#include <qtooltip.h>

cSession::cSession (int sess, QWidget *parent, const char *name) :
    QVBox (parent, name), cActionBase ("session", sess)
{
  _flashing = false;
  defaultName = true;

  //create objects
  _telnet = new cTelnet (sess);
#ifdef HAVE_MXP
  _mxpmanager = new cMXPManager (sess);
#endif
  _ansiparser = new cANSIParser (sess);
  _parser = new cCmdParser (sess);
  _cmdproc = new cCmdProcessor (sess);
  _cmdqueues = new cCmdQueues (sess);
  _textproc = new cTextProcessor (sess);
  _connection = new cConnection (sess);
  
  _output = new cOutput (sess, this);
  
  QHBox *promptinput = new QHBox (this);
  _prompt = new cPrompt (sess, promptinput);
  
  _inputline = new cInputLine (sess, "inputline", promptinput);
  _inputline->initialize ();
  
  _multiinputline = new cMultiInputLine (sess, promptinput);
  _multiinputline->hide ();
  QToolTip::add (_multiinputline, i18n ("Ctrl+Enter adds new line, unless changed in settings"));
  
  KPushButton *switchlinebutton = new KPushButton (promptinput);
  KIconLoader *icons = (KApplication::kApplication())->iconLoader ();
  switchlinebutton->setPixmap (icons->loadIcon ("text_center", KIcon::Small, 16));
  QToolTip::add (switchlinebutton, i18n ("Switches between standard and multi-line input line."));
  
  //the button should take as few space as possible
  switchlinebutton->setSizePolicy (QSizePolicy::Fixed, QSizePolicy::Minimum);
  switchlinebutton->setFocusPolicy (QWidget::NoFocus);
 
  _auxinputline = new cInputLine (sess, "auxinputline", this);
  _auxinputline->initialize ();
  _auxinputline->hide ();
  
  _gaugebar = new cGaugeBar (sess, this);
  _gaugebar->hide();

  KStatusBar *statusbar = new KStatusBar (this);
  _status = new cStatus (sess, statusbar);

  _transcript = new cTranscript (sess);

  //the button switches between standard input and multi-line input
  connect (switchlinebutton, SIGNAL (clicked ()), this, SLOT (switchInputLines ()));

  KApplication::kApplication()->processEvents ();

}

cSession::~cSession ()
{
  //transcript must be deleted before the console!
  delete _transcript;

  delete _status;  //this also destroys the statusbar
  delete _multiinputline;
  delete _auxinputline;
  delete _inputline;
  delete _output;
  delete _prompt;

  delete _connection;
  delete _textproc;
  delete _cmdqueues;
  delete _cmdproc;
  delete _parser;
  delete _ansiparser;
#ifdef HAVE_MXP
  delete _mxpmanager;
#endif
  delete _telnet;
}

QString cSession::actionHandler (QString action, int)
{
  if (action == "name")
    return name();

  return QString::null;
}

void cSession::setName (const QString &name, bool defName)
{
  //don't overwrite non-default name with a default one
  if (defName && (!defaultName))
    return;
  
  _name = name;
  defaultName = defName;
}

void cSession::setAuxInput (bool val)
{
  val ? _auxinputline->show () : _auxinputline->hide ();
}

void cSession::switchInputLines ()
{
  if (_inputline->isVisible())
  {
    _inputline->hide();
    _multiinputline->show();
    _multiinputline->setFocus ();
  }
  else
  {
    _multiinputline->hide();
    _inputline->show();
    _inputline->setFocus ();
  }
}
